pub struct UpgradeDialog {
version_combo: TemplateChild<ComboRow>,
invite_only_warning_label: TemplateChild<Label>,
creators_warning_label: TemplateChild<Label>,
header_factory: OnceCell<SignalListItemFactory>,
notifier: OnceCell<OneshotNotifier<Option<RoomVersionId>>>,
}Fields
version_combo: TemplateChild<ComboRow>invite_only_warning_label: TemplateChild<Label>creators_warning_label: TemplateChild<Label>header_factory: OnceCell<SignalListItemFactory>notifier: OnceCell<OneshotNotifier<Option<RoomVersionId>>>The notifier for the response of the user.
Implementations
Sourceimpl UpgradeDialog
impl UpgradeDialog
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl UpgradeDialog
impl UpgradeDialog
Sourcefn notifier(&self) -> &OneshotNotifier<Option<RoomVersionId>>
fn notifier(&self) -> &OneshotNotifier<Option<RoomVersionId>>
The notifier for the response of the user.
Sourcefn header_factory(&self) -> &SignalListItemFactory
fn header_factory(&self) -> &SignalListItemFactory
The header factory to separate stable from experimental versions.
Sourcepub(super) async fn confirm_upgrade(
&self,
info: &UpgradeInfo,
parent: &Widget,
) -> Option<RoomVersionId>
pub(super) async fn confirm_upgrade( &self, info: &UpgradeInfo, parent: &Widget, ) -> Option<RoomVersionId>
Ask the user to confirm the room upgrade and select a room version among the ones that are supported by the server.
Returns the selected room version, or None if the user cancelled
the upgrade.
Sourcefn update_version_combo(&self, info: &UpgradeInfo)
fn update_version_combo(&self, info: &UpgradeInfo)
Update the room versions combo row with the given details.
Sourcefn update_invite_only_warning(&self, info: &UpgradeInfo)
fn update_invite_only_warning(&self, info: &UpgradeInfo)
Update the invite-only warning.
Sourcefn update_creators_warning(&self, info: &UpgradeInfo)
fn update_creators_warning(&self, info: &UpgradeInfo)
Update the creators warning.